pub enum DbSignetEvent {
Transact(u64, Transact),
Enter(u64, Enter),
EnterToken(u64, EnterToken),
}Expand description
Extracted Signet events, stored in cold storage.
This is an implementation detail of the SignetEvents table, and should
not generally be used outside the cold-storage DB module.
The first element of each event tuple is the event’s order within all events in the block.
The second element is the event itself.
Variants
Transact(u64, Transact)
Each Transact event is stored as a separate entry in the same table.
Enter(u64, Enter)
Each Enter event is stored as a separate entry in the same table.
EnterToken(u64, EnterToken)
Each EnterToken event is stored as a separate entry in the same table.